@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous  *
  *                  mode detection and handling.              *
  *                                                            *
- * Version:         1.0.2                                     *
+ * Version:         1.0.3                                     *
  *                                                            *
  * ---------------------------------------------------------- *
  *                                                            *
@@ -505,69 +505,12 @@ int main( int argc, char **argv )
     newMask = sigsetInit();
 
     /*
-     * Create a POSIX interval timer to send SIGUSR1 to ourselves.
-     * This timer triggers network interface status scans.
+     * Call pTimerInit to initialize our POSIX timers. When fired,
+     * an interface status dump and/or metrics dump is initiated.
      */
-    evpTimer.sigev_notify = SIGEV_SIGNAL;
-    evpTimer.sigev_signo = SIGUSR1;
-
-    if( timer_create( CLOCK_REALTIME, &evpTimer, &timerOne ) != 0 )
+    if( ( pTimerInit( ifStatusSecs, ifMetricSecs ) ) != 0 )
     {
-        errHandler( "ERROR: timer_create(): could not create interval timer: %s\n",
-                                                                  strerror( errno ) );
-        exit( EXIT_FAILURE );
-     }
-
-    /*
-     * Specify that initially, the SIGUSR1 timer will fire one second after
-     * being armed and then every ifStatusSecs (user defined) thereafter.
-     */
-    spec.it_value.tv_sec = 1;
-    spec.it_value.tv_nsec = 0;
-    spec.it_interval.tv_sec = ifStatusSecs;
-    spec.it_interval.tv_nsec = 0;
-
-    /*
-     * Arm the SIGUSR1 timer.
-     */
-    if( timer_settime( timerOne, 0, &spec, NULL ) != 0 )
-    {
-        errHandler( "ERROR: timer_settime(): could not arm interval timer: %s\n",
-                                                                strerror( errno ) );
-        exit( EXIT_FAILURE );
-     }
-
-    /*
-     * Create a POSIX interval timer to send SIGUSR2 to ourselves.
-     * This timer triggers network interface metrics dumps.
-     */
-    evpTimer.sigev_notify = SIGEV_SIGNAL;
-    evpTimer.sigev_signo = SIGUSR2;
-
-    if( timer_create( CLOCK_REALTIME, &evpTimer, &timerTwo ) != 0 )
-    {
-        errHandler( "ERROR: timer_create(): could not create interval timer: %s\n",
-                                                                  strerror( errno ) );
-        exit( EXIT_FAILURE );
-     }
-
-    /*
-     * Specify that initially, the SIGUSR2 timer will fire one second after
-     * being armed and then every ifMetricSecs (user defined) thereafter.
-     */
-    spec.it_value.tv_sec = 1;
-    spec.it_value.tv_nsec = 0;
-    spec.it_interval.tv_sec = ifMetricSecs;
-    spec.it_interval.tv_nsec = 0;
-
-    /*
-     * Arm the SIGUSR2 timer.
-     */
-    if( timer_settime( timerTwo, 0, &spec, NULL ) != 0 )
-    {
-        errHandler( "ERROR: timer_settime(): could not arm interval timer: %s\n",
-                                                                strerror( errno ) );
-        exit( EXIT_FAILURE );
+	exit( EXIT_FAILURE );
      }
 
     /*
