@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous     *
  *                  mode detection and handling.                 *
  *                                                               *
- * Version:         1.0.2                                        *
+ * Version:         1.0.3                                        *
  *                                                               *
  * ------------------------------------------------------------- *
  *                                                               *
@@ -75,6 +75,15 @@ sigset_t sigsetInit()
         exit( EXIT_FAILURE );
      }
 
+    /*
+     * Add SIGHUP to newMask.
+     */
+    if( sigaddset( &newMask, SIGHUP ) != 0 )
+    {
+        errHandler( "ERROR: sigaddset(): could not add SIGHUP to signal set: %s\n",
+                                                                  strerror( errno ) );
+        exit( EXIT_FAILURE );
+     }
     /*
      * Add SIGINT to newMask.
      */
